@@ -28,11 +28,12 @@ class PythonBuilder(AbstractBuilder):
     def config(self):
         return self.python_worktree.config
 
-    def bootstrap(self, remote_packages=None):
+    def bootstrap(self, remote_packages=None, site_packages=True):
         qipy.venv.configure_virtualenv(self.config,
                                        self.python_worktree,
                                        build_worktree=self.build_worktree,
-                                       remote_packages=remote_packages)
+                                       remote_packages=remote_packages,
+                                       site_packages=site_packages)
         qi_path_sdk_dirs = [p.sdk_directory for p in self.build_worktree.build_projects]
         write_qi_path_conf(self.python_worktree.venv_path, qi_path_sdk_dirs)
 
@@ -49,8 +50,10 @@ class PythonBuilder(AbstractBuilder):
                           ui.reset, ui.blue, project.name)
             setup_py = os.path.join(project.path, "setup.py")
             python = self.python_worktree.python
+            if not os.path.exists(python):
+                raise Exception("Please call `qipy bootstrap`")
             subprocess.check_call([python, setup_py, "install",
-                                   "--root", dest, '--prefix='],
+                                   "--root", dest, "--prefix=."],
                                    cwd=project.path)
         # Also install a python wrapper so that everything goes smoothly
         to_write="""\
