@@ -1,4 +1,4 @@
-## Copyright (c) 2012, 2013 Aldebaran Robotics. All rights reserved.
+## Copyright (c) 2012-2014 Aldebaran Robotics. All rights reserved.
 ## Use of this source code is governed by a BSD-style license that can be
 ## found in the COPYING file.
 """ Toolchain
@@ -344,7 +344,7 @@ class Toolchain(object):
         """
         lines = ["# Autogenerated file. Do not edit\n",
                  "# Make sure we don't keep adding elements to this list:\n",
-                 "set(CMAKE_FIND_ROOT_PATH "" CACHE INTERNAL "" FORCE)\n",
+                 "set(CMAKE_PREFIX_PATH "" CACHE INTERNAL "" FORCE)\n",
                  "set(CMAKE_FRAMEWORK_PATH "" CACHE INTERNAL "" FORCE)\n"
         ]
 
@@ -354,8 +354,8 @@ class Toolchain(object):
                 lines.append('include("%s")\n' % tc_file)
         for package in self.packages:
             package_path = qisys.sh.to_posix_path(package.path)
-            lines.append('list(INSERT CMAKE_FIND_ROOT_PATH 0 "%s")\n' % package_path)
-            # For some reason CMAKE_FRAMEWORK_PATH does not follow CMAKE_FIND_ROOT_PATH
+            lines.append('list(INSERT CMAKE_PREFIX_PATH 0 "%s")\n' % package_path)
+            # For some reason CMAKE_FRAMEWORK_PATH does not follow CMAKE_PREFIX_PATH
             # (well, you seldom use frameworks when cross-compiling ...), so we
             # need to change this variable too
             lines.append('list(INSERT CMAKE_FRAMEWORK_PATH 0 "%s")\n' % package_path)
